<?php // Register custom hooks to for the theme

/* ------------ */
/* Header Hooks */
/* ------------ */

function rem_header_before() { 
	do_action('rem_header_before');
}
function rem_header_after() { 
	do_action('rem_header_after');
}
function rem_header_begin() { 
	do_action('rem_header_begin');
}
function rem_header_end() { 
	do_action('rem_header_end');
}
function rem_header_upper_begin() {
    do_action('rem_header_upper_begin');
}
function rem_header_upper_end() {
    do_action('rem_header_upper_end');
}
function rem_header_main_begin() {
	do_action('rem_header_main_begin');
}
function rem_header_main_end() {
	do_action('rem_header_main_end');
}
function rem_header_lower_begin() {
    do_action('rem_header_lower_begin');
}
function rem_header_lower_end() {
    do_action('rem_header_lower_end');
}


/* ------------ */
/* Footer Hooks */
/* ------------ */

function rem_footer_begin() { 
	do_action('rem_footer_begin');
}
function rem_footer_end() { 
	do_action('rem_footer_end');
}
function rem_footer_upper_begin() {
	do_action('rem_footer_upper_begin');
}
function rem_footer_upper_end() {
	do_action('rem_footer_upper_end');
}
function rem_footer_main_begin() {
	do_action('rem_footer_main_begin');
}
function rem_footer_main_end() {
	do_action('rem_footer_main_end');
}