<?php $header_type = get_theme_mod( 'header_type' ); ?>
<header class="site-header <?php echo $header_type ?>" >
	
	<?php // Hook: at the start of the header
    rem_header_begin(); ?>
    
    <div class="upper container_wrap">
    	<div class="container">
    	    
    	<?php // Hook: at the start of the header upper section
        rem_header_upper_begin(); ?>   
        
        <?php // Top header nav
        get_template_part('template-parts/navigation/header', 'top'); ?>  
        
        <?php // Hook: at the end of the header upper section
        rem_header_upper_end(); ?>   
        
        </div>
    </div>
    
    <div class="main container_wrap">
    	<div class="container">
	    
	    <?php // Hook: at the start of the header container
        rem_header_main_begin(); ?>
        
		<?php // Site logo
		get_template_part('template-parts/misc/custom', 'logo'); ?>  
		
		<?php // Tagline
		get_template_part('template-parts/misc/content', 'tagline'); ?>
		    
		<?php // Main nav menu
		get_template_part('template-parts/navigation/header', 'main'); ?> 
		
		<?php // Hook: at the end of the header container
        rem_header_main_end(); ?>
        
        </div>
	</div>
	
	<?php // Hook: at the end of the header
    rem_header_end(); ?>
	
</header>